@@ -230,6 +230,19 @@ setMethod (f='names<-', signature='TimeInstantDataFrame',
 	   } )
 
 # Math
+#-----
+setMethod ('Ops', c('TimeInstantDataFrame', 'numeric'),
+	function (e1, e2) {
+		e1@data <- as.data.frame(
+			do.call(.Generic, list(e1=e1@data, e2=e2)))
+		return (e1)
+	})
+setMethod ('Ops', c('numeric', 'TimeInstantDataFrame'),
+	function (e1, e2) {
+		e2@data <- as.data.frame(
+			do.call(.Generic, list(e1=e1, e2=e2@data)))
+		return (e2)
+	})
 
 # manipulation
 #-------------
@@ -282,7 +295,8 @@ setMethod ('lapply', signature('TimeInstantDataFrame', 'ANY'),
 				     timezone=timezone(X),
 				     data=data.frame (res))
 		   } else {
-			   stop ("try to apply inadequate function over TimeInstantDataFrame.")
+			   X <- data.frame(res)
+			   warning ("Result can not be converted to a TimeInstantDataFrame, a data.frame is returned.")
 		   }
 		   return (X)
 	   } )
